precision highp float;
varying vec2 refreshTextureCoordinate;
varying vec2 imageTextureCoordinate;
varying vec2 centers;

uniform sampler2D inputImageTexture;
uniform sampler2D inputPenTexture;
uniform sampler2D overlapTexture;

uniform vec2 texSize;
uniform vec2 mosaicSize;
uniform float overlapImageScale;
void main()
{
    vec4 pen = texture2D(inputPenTexture,imageTextureCoordinate);
    vec2 intXY = vec2(refreshTextureCoordinate.x * texSize.x, refreshTextureCoordinate.y * texSize.y);
    vec2 XYMosaic = vec2(floor(intXY.x / mosaicSize.x) * mosaicSize.x,floor(intXY.y / mosaicSize.y) * mosaicSize.y);
    vec2 UVMosaic = vec2(XYMosaic.x / texSize.x,XYMosaic.y / texSize.y);
    vec4 result = texture2D(inputImageTexture,UVMosaic);
    
    // overlap do something
    vec2 overlapSampleDivisor = vec2(mosaicSize.x / texSize.x * overlapImageScale, mosaicSize.y / texSize.y * overlapImageScale);
    
    float xIndex = ceil(refreshTextureCoordinate.x / overlapSampleDivisor.x);
    float yIndex = ceil(refreshTextureCoordinate.y / overlapSampleDivisor.y);
    
    vec2 overlapTextureCoord;
    overlapTextureCoord.x = (refreshTextureCoordinate.x - (overlapSampleDivisor.x * (xIndex - 1.0))) / overlapSampleDivisor.x;
    overlapTextureCoord.y = (refreshTextureCoordinate.y - (overlapSampleDivisor.y * (yIndex - 1.0))) / overlapSampleDivisor.y;
    
    vec4 overlapTextureColor = texture2D(overlapTexture,overlapTextureCoord);
    
    float alpha = overlapTextureColor.a;
    float newR = result.r * (1.0 - alpha) + overlapTextureColor.r * alpha;
    float newG = result.g * (1.0 - alpha) + overlapTextureColor.g * alpha;
    float newB = result.b * (1.0 - alpha) + overlapTextureColor.b * alpha;
    
    
    newR = max(0.0,min(1.0, newR));
    newG = max(0.0,min(1.0, newG));
    newB = max(0.0,min(1.0, newB));
    
    gl_FragColor = vec4(newR,newG,newB,pen.a);
}